@@ -20,13 +20,13 @@ describe 'tripleo::profile::base::nova::api' do
   shared_examples_for 'tripleo::profile::base::nova::api' do
     let(:pre_condition) do
       <<-eos
-      class { '::tripleo::profile::base::nova':
+      class { 'tripleo::profile::base::nova':
         step => #{params[:step]},
         oslomsg_rpc_hosts    => [ 'localhost' ],
         oslomsg_rpc_username => 'nova',
         oslomsg_rpc_password => 'foo'
       }
-      class { '::tripleo::profile::base::nova::authtoken':
+      class { 'tripleo::profile::base::nova::authtoken':
         step => #{params[:step]},
       }
 eos
@@ -43,8 +43,6 @@ eos
         is_expected.to_not contain_class('nova::keystone::authtoken')
         is_expected.to_not contain_class('nova::api')
         is_expected.to_not contain_class('nova::cors')
-        is_expected.to_not contain_class('nova::pci')
-        is_expected.to_not contain_class('nova::vendordata')
         is_expected.to_not contain_class('nova::network::neutron')
         is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
@@ -63,29 +61,25 @@ eos
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
         is_expected.to contain_class('nova::cors')
-        is_expected.to contain_class('nova::pci')
-        is_expected.to contain_class('nova::vendordata')
         is_expected.to contain_class('nova::network::neutron')
         is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
 
-    context 'with step 3 not on bootstrap node' do
+    context 'with step 3 on bootstrap node' do
       let(:params) { {
         :step => 3,
-        :bootstrap_node => 'other.example.com',
+        :bootstrap_node => 'node.example.com',
       } }
 
       it {
         is_expected.to contain_class('tripleo::profile::base::nova::api')
         is_expected.to contain_class('tripleo::profile::base::nova')
-        is_expected.to_not contain_class('nova::cell_v2::simple_setup')
+        is_expected.to contain_class('nova::cell_v2::simple_setup')
         is_expected.to contain_class('nova::keystone::authtoken')
-        is_expected.to_not contain_class('nova::api')
-        is_expected.to_not contain_class('nova::cors')
-        is_expected.to_not contain_class('nova::pci')
-        is_expected.to_not contain_class('nova::vendordata')
-        is_expected.to_not contain_class('nova::network::neutron')
+        is_expected.to contain_class('nova::api')
+        is_expected.to contain_class('nova::cors')
+        is_expected.to contain_class('nova::network::neutron')
         is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
@@ -120,8 +114,6 @@ eos
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
         is_expected.to contain_class('nova::cors')
-        is_expected.to contain_class('nova::pci')
-        is_expected.to contain_class('nova::vendordata')
         is_expected.to contain_class('nova::network::neutron')
         is_expected.to contain_class('nova::wsgi::apache_api')
       }
