@@ -40,14 +40,14 @@ describe 'tripleo::profile::base::nova::compute' do
     context 'with step 5' do
       let(:pre_condition) do
         <<-eos
-        class { '::tripleo::profile::base::nova':
+        class { 'tripleo::profile::base::nova':
           step => #{params[:step]},
           oslomsg_rpc_hosts => [ '127.0.0.1' ],
         }
-        class { '::tripleo::profile::base::nova::migration':
+        class { 'tripleo::profile::base::nova::migration':
           step => #{params[:step]}
         }
-        class { '::tripleo::profile::base::nova::migration::client':
+        class { 'tripleo::profile::base::nova::migration::client':
           step => #{params[:step]}
         }
 eos
