@@ -20,7 +20,7 @@ describe 'tripleo::profile::base::nova::conductor' do
   shared_examples_for 'tripleo::profile::base::nova::conductor' do
     let(:pre_condition) do
       <<-eos
-      class { '::tripleo::profile::base::nova':
+      class { 'tripleo::profile::base::nova':
         step => #{params[:step]},
         oslomsg_rpc_hosts => [ '127.0.0.1' ],
       }
@@ -34,7 +34,6 @@ eos
         is_expected.to contain_class('tripleo::profile::base::nova::conductor')
         is_expected.to contain_class('tripleo::profile::base::nova')
         is_expected.to_not contain_class('nova::conductor')
-        is_expected.to_not contain_class('nova::network::neutron')
       }
     end
 
@@ -45,7 +44,6 @@ eos
         is_expected.to contain_class('tripleo::profile::base::nova::conductor')
         is_expected.to contain_class('tripleo::profile::base::nova')
         is_expected.to contain_class('nova::conductor')
-        is_expected.to contain_class('nova::network::neutron')
       }
     end
   end
